#!/bin/sh

set -e
. ./testsuite/common.sh

testpkg='testsuite/data/pearpkg1'

expect_equal "php lib/scripts/phppkginfo summary '${testpkg}'" 'this is a wrapper package for installing dependencies for MyProject'
