#!/bin/sh

set -e
. ./testsuite/common.sh

testpkg='testsuite/data/pearpkg1'

ret=0
expect_equal 'php lib/scripts/phppkginfo debian_pkgname pear.horde.org horde' 'php-horde' || ret=$?
expect_equal 'php lib/scripts/phppkginfo debian_pkgname pecl.php.net spl' '' || ret=$?
expect_equal 'php lib/scripts/phppkginfo debian_pkgname pecl.php.net SPL' '' || ret=$?
expect_equal 'php lib/scripts/phppkginfo debian_pkgname pear.php.net Net_SMTP' 'php-net-smtp' || ret=$?

exit $ret
