#!/bin/sh

set -e
. ./testsuite/common.sh

testpkg='testsuite/data/pearpkg1'
testpecl='testsuite/data/peclpkg1'

ret=0

expect_equal "php lib/scripts/phppkginfo package_type '${testpkg}'" 'php' || ret=$?
expect_equal "php lib/scripts/phppkginfo package_type '${testpecl}'" 'extsrc' || ret=$?

exit $ret
